@@ -1,6 +1,7 @@
 """ utilities for hypersolver """
 
 import os
+
 import numpy as np
 # pytype: disable=import-error
 if os.environ.get("HS_BACKEND", "numpy") == "jax":
@@ -8,7 +9,7 @@ if os.environ.get("HS_BACKEND", "numpy") == "jax":
 
 
 def set_xnp(backend=os.environ.get("HS_BACKEND", "numpy")):
-    """ wrapper to set select numpy or jax.numpy """
+    """ wrapper to set numpy or jax.numpy """
 
     return jnp if backend == "jax" else np
 
@@ -23,7 +24,7 @@ def term_util(term, orig):
         by making it look like the "orig" input
     """
 
-    if isinstance(term, xnp.ndarray) and xnp.array(term).shape == orig.shape:
+    if isinstance(term, type(orig)) and xnp.array(term).shape == orig.shape:
         return term
 
     return xnp.full_like(orig, term)
@@ -42,5 +43,5 @@ def time_step_util(vars_vals, flux_term, stability):
         stability = xnp.array([0.98])
 
     return xnp.array(stability) * xnp.array(
-        vars_vals[1:] - vars_vals[:1]
+        vars_vals[1:] - vars_vals[:-1]
     ).min() / xnp.array(flux_term).max()
